@@ -13,16 +13,18 @@ from typing import TYPE_CHECKING, Any
 
 import rich.repr
 
-from .. import events
-from .._loop import loop_last
-from .._parser import ParseError
-from .._xterm_parser import XTermParser
-from ..driver import Driver
-from ..geometry import Size
-from ._writer_thread import WriterThread
+from textual import events
+from textual._loop import loop_last
+from textual._parser import ParseError
+from textual._xterm_parser import XTermParser
+from textual.driver import Driver
+from textual.drivers._writer_thread import WriterThread
+from textual.geometry import Size
+from textual.message import Message
+from textual.messages import TerminalSupportInBandWindowResize
 
 if TYPE_CHECKING:
-    from ..app import App
+    from textual.app import App
 
 
 @rich.repr.auto(angular=True)
@@ -59,6 +61,7 @@ class LinuxDriver(Driver):
         # need to know that we came in here via a SIGTSTP; this flag helps
         # keep track of this.
         self._must_signal_resume = False
+        self._in_band_window_resize = False
 
         # Put handlers for SIGTSTP and SIGCONT in place. These are necessary
         # to support the user pressing Ctrl+Z (or whatever the dev might
@@ -135,6 +138,22 @@ class LinuxDriver(Driver):
         """Enable bracketed paste mode."""
         self.write("\x1b[?2004h")
 
+    def _query_in_band_window_resize(self) -> None:
+        self.write("\x1b[?2048$p")
+
+    def _enable_in_band_window_resize(self) -> None:
+        self.write("\x1b[?2048h")
+
+    def _enable_line_wrap(self) -> None:
+        self.write("\x1b[?7h")
+
+    def _disable_line_wrap(self) -> None:
+        self.write("\x1b[?7l")
+
+    def _disable_in_band_window_resize(self) -> None:
+        if self._in_band_window_resize:
+            self.write("\x1b[?2048l")
+
     def _disable_bracketed_paste(self) -> None:
         """Disable bracketed paste mode."""
         self.write("\x1b[?2004l")
@@ -197,6 +216,8 @@ class LinuxDriver(Driver):
         loop = asyncio.get_running_loop()
 
         def send_size_event() -> None:
+            if self._in_band_window_resize:
+                return
             terminal_size = self._get_terminal_size()
             width, height = terminal_size
             textual_size = Size(width, height)
@@ -246,14 +267,15 @@ class LinuxDriver(Driver):
         self.write("\x1b[?25l")  # Hide cursor
         self.write("\x1b[?1004h")  # Enable FocusIn/FocusOut.
         self.write("\x1b[>1u")  # https://sw.kovidgoyal.net/kitty/keyboard-protocol/
-        # Disambiguate escape codes https://sw.kovidgoyal.net/kitty/keyboard-protocol/#progressive-enhancement
-        self.write("\x1b[=1;u")
+
         self.flush()
         self._key_thread = Thread(target=self._run_input_thread)
         send_size_event()
         self._key_thread.start()
         self._request_terminal_sync_mode_support()
+        self._query_in_band_window_resize()
         self._enable_bracketed_paste()
+        self._disable_line_wrap()
 
         # Appears to fix an issue enabling mouse support in iTerm 3.5.0
         self._enable_mouse_support()
@@ -330,6 +352,8 @@ class LinuxDriver(Driver):
     def stop_application_mode(self) -> None:
         """Stop application mode, restore state."""
         self._disable_bracketed_paste()
+        self._enable_line_wrap()
+        self._disable_in_band_window_resize()
         self.disable_input()
 
         if self.attrs_before is not None:
@@ -341,6 +365,7 @@ class LinuxDriver(Driver):
         # Disable the Kitty keyboard protocol. This must be done before leaving
         # the alt screen. https://sw.kovidgoyal.net/kitty/keyboard-protocol/
         self.write("\x1b[<u")
+
         # Alt screen false, show cursor
         self.write("\x1b[?1049l")
         self.write("\x1b[?25h")
@@ -401,13 +426,14 @@ class LinuxDriver(Driver):
                         # This can occur if the stdin is piped
                         break
                     for event in feed(unicode_data):
-                        self.process_event(event)
+                        self.process_message(event)
             for event in tick():
-                self.process_event(event)
+                self.process_message(event)
 
         try:
             while not self.exit_event.is_set():
                 process_selector_events(selector.select(0.1))
+            selector.unregister(self.fileno)
             process_selector_events(selector.select(0.1), final=True)
 
         finally:
@@ -417,3 +443,22 @@ class LinuxDriver(Driver):
                     pass
             except ParseError:
                 pass
+
+    def process_message(self, message: Message) -> None:
+        # intercept in-band window resize
+        if isinstance(message, TerminalSupportInBandWindowResize):
+            # If it is supported, enabled it
+            if message.supported and not message.enabled:
+                self._enable_in_band_window_resize()
+                self._in_band_window_resize = message.supported
+            elif message.enabled:
+                self._in_band_window_resize = message.supported
+            # Send up-to-date message
+            super().process_message(
+                TerminalSupportInBandWindowResize(
+                    message.supported, self._in_band_window_resize
+                )
+            )
+            return
+
+        super().process_message(message)
