@@ -147,10 +147,9 @@ class Screen(Generic[ScreenResultType], Widget):
 
     DEFAULT_CSS = """
     Screen {
-    
         layout: vertical;
         overflow-y: auto;
-        background: $surface;        
+        background: $background;        
         
         &:inline {
             height: auto;
@@ -267,6 +266,9 @@ class Screen(Generic[ScreenResultType], Widget):
         self.bindings_updated_signal: Signal[Screen] = Signal(self, "bindings_updated")
         """A signal published when the bindings have been updated"""
 
+        self._css_update_count = -1
+        """Track updates to CSS."""
+
     @property
     def is_modal(self) -> bool:
         """Is the screen modal?"""
@@ -744,12 +746,15 @@ class Screen(Generic[ScreenResultType], Widget):
         """
         return self._move_focus(-1, selector)
 
-    def maximize(self, widget: Widget, container: bool = True) -> None:
+    def maximize(self, widget: Widget, container: bool = True) -> bool:
         """Maximize a widget, so it fills the screen.
 
         Args:
             widget: Widget to maximize.
             container: If one of the widgets ancestors is a maximizeable widget, maximize that instead.
+
+        Returns:
+            `True` if the widget was maximized, otherwise `False`.
         """
         if widget.allow_maximize:
             if container:
@@ -759,9 +764,11 @@ class Screen(Generic[ScreenResultType], Widget):
                         break
                     if maximize_widget.allow_maximize:
                         self.maximized = maximize_widget
-                        return
+                        return True
 
             self.maximized = widget
+            return True
+        return False
 
     def minimize(self) -> None:
         """Restore any maximized widget to normal state."""
@@ -780,6 +787,10 @@ class Screen(Generic[ScreenResultType], Widget):
         """Action to minimize the currently maximized widget."""
         self.minimize()
 
+    def action_blur(self) -> None:
+        """Action to remove focus (if set)."""
+        self.set_focus(None)
+
     def _reset_focus(
         self, widget: Widget, avoiding: list[Widget] | None = None
     ) -> None:
@@ -1205,8 +1216,9 @@ class Screen(Generic[ScreenResultType], Widget):
 
     def _screen_resized(self, size: Size):
         """Called by App when the screen is resized."""
-        self._compositor_refresh()
-        self._refresh_layout(size)
+        if self.stack_updates:
+            self._compositor_refresh()
+            self._refresh_layout(size)
 
     def _on_screen_resume(self) -> None:
         """Screen has resumed."""
@@ -1364,6 +1376,7 @@ class Screen(Generic[ScreenResultType], Widget):
         the origin of the specified region.
         """
         return events.MouseMove(
+            event.widget,
             event.x - region.x,
             event.y - region.y,
             event.delta_x,
